"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _fileUtils = require("../../utils/fileUtils");
var _logger = require("../../utils/logger");
var _readConfigFile = require("./readConfigFile");
var _checkAuthDirectory = require("./helpers/checkAuthDirectory");
function deleteAuthFiles(authFilePath) {
  authFilePath = _path.default.resolve(process.cwd(), authFilePath);
  const authFileFolder = _path.default.dirname(authFilePath);
  _logger.Logger.log(_logger.Logger.INFO_TYPE, `Deleting auth files present in ${authFileFolder}`);
  (0, _fileUtils.deleteFolder)(authFileFolder);
}
function deletePlaywrightReport(reportPath) {
  _logger.Logger.log(_logger.Logger.INFO_TYPE, `Deleting Playwright report ${reportPath}`);
  (0, _fileUtils.deleteFolder)(reportPath);
}
function deleteGeneratedFeatures() {
  const featuresGenPath = _path.default.resolve(process.cwd(), 'uat', '.features-gen');
  _logger.Logger.log(_logger.Logger.INFO_TYPE, `Deleting generated features at ${featuresGenPath}`);
  (0, _fileUtils.deleteFolder)(featuresGenPath);
}
function deleteLockFiles() {
  const lockFilePath = (0, _checkAuthDirectory.getLockDirectoryPath)();
  _logger.Logger.log(_logger.Logger.INFO_TYPE, `Deleting lock files at ${lockFilePath}`);
  (0, _fileUtils.deleteFolder)(lockFilePath);
}
function clearCaches() {
  try {
    const {
      authFilePath,
      reportPath
    } = (0, _readConfigFile.generateConfigFromFile)();
    deleteAuthFiles(authFilePath);
    deletePlaywrightReport(reportPath);
    deleteGeneratedFeatures();
    deleteLockFiles();
    _logger.Logger.log(_logger.Logger.SUCCESS_TYPE, 'Caches Cleared. Now you can try running npm run uat');
  } catch (err) {
    _logger.Logger.error(err);
    _logger.Logger.log(_logger.Logger.FAILURE_TYPE, 'Error While clearing cookies. Try manually delete folder uat/playwright and uat/playwright-report');
  }
}
var _default = exports.default = clearCaches;