"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAuthFileDirectory = getAuthFileDirectory;
exports.loadCookiesIfPresent = loadCookiesIfPresent;
exports.verifyIfCookieFileExists = verifyIfCookieFileExists;
var _path = _interopRequireDefault(require("path"));
var _fs = require("fs");
var _readConfigFile = require("../../readConfigFile");
var _checkAuthDirectory = require("../checkAuthDirectory");
var _logger = require("../../../../utils/logger");
/* eslint-disable no-console */

const authContent = {
  cookies: []
};
function getAuthFileDirectory() {
  const {
    uatDirectory
  } = (0, _readConfigFile.generateConfigFromFile)();
  return _path.default.resolve(_path.default.join(uatDirectory, 'playwright', '.auth'));
}
function verifyIfCookieFileExists(authFile) {
  (0, _checkAuthDirectory.createAuthDirectoryIfNotExist)();
  if (!(0, _fs.existsSync)(authFile)) {
    console.log('creating auth file..');
    (0, _fs.writeFileSync)(authFile, JSON.stringify(authContent, null, 2));
  }
}
function convertCookiesToParse(cookies, authFilePath) {
  try {
    return JSON.parse(cookies);
  } catch (err) {
    _logger.Logger.error(err);
    throw new Error(` Error while parsing cookies ${err} \n${_path.default.resolve(process.cwd(), authFilePath)} File is Empty`);
  }
}
async function loadCookiesIfPresent(page, authFile) {
  verifyIfCookieFileExists(authFile);
  const cookies = (0, _fs.readFileSync)(authFile);
  const parsedCookies = convertCookiesToParse(cookies, authFile);
  await page.context().addCookies(parsedCookies.cookies === undefined ? [] : parsedCookies.cookies);
}