"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.checkIfFileExists = checkIfFileExists;
exports.deleteFile = deleteFile;
exports.deleteFolder = deleteFolder;
exports.readFileContents = readFileContents;
exports.writeFileContents = writeFileContents;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _logger = require("./logger");
function checkIfFileExists(file) {
  try {
    _fs.default.accessSync(file, _fs.default.constants.F_OK);
    return true;
  } catch (err) {
    _logger.Logger.error(err);
    return false;
  }
}
function readFileContents(filePath) {
  try {
    let fileContents = _fs.default.readFileSync(filePath, 'utf-8');
    return fileContents;
  } catch (err) {
    _logger.Logger.error(err);
    return null;
  }
}
function writeFileContents(filePath, content, writeOptions = {}) {
  const directoryPath = _path.default.dirname(filePath);

  // Check if the directory exists
  if (!_fs.default.existsSync(directoryPath)) {
    _fs.default.mkdirSync(directoryPath, {
      recursive: true
    });
  }
  try {
    _fs.default.writeFileSync(`${filePath}`, content, writeOptions);
  } catch (err) {
    _logger.Logger.error(err);
    throw new Error(err);
  }
}
function deleteFile(filePath) {
  if (checkIfFileExists(filePath)) {
    try {
      _fs.default.unlinkSync(filePath);
    } catch (err) {
      _logger.Logger.error(err);
      throw new Error(`Error while deleting the test data file: ${filePath}`);
    }
  } else {
    _logger.Logger.log(_logger.Logger.INFO_TYPE, `File Does not Exist in the path ${filePath}`);
  }
}
function deleteFolder(folderPath) {
  if (_fs.default.existsSync(folderPath)) {
    try {
      _fs.default.rmdirSync(folderPath, {
        recursive: true
      });
    } catch (err) {
      _logger.Logger.error(err);
      throw new Error(`Error while deleting the test data file: ${folderPath}`);
    }
  }
}